@@ -14,12 +14,12 @@ import org.gnu.glib.Handle;
 
 public class Cursor extends Boxed {
 
-    protected Cursor( Handle hndl ) {
-        super( hndl );
+    protected Cursor(Handle hndl) {
+        super(hndl);
     }
 
     /**
-     *	Creates a new cursor from the set of builtin cursors.
+     * Creates a new cursor from the set of builtin cursors.
      */
     public Cursor(CursorType ctype) {
         super(gdk_cursor_new(ctype.getValue()));
@@ -28,26 +28,26 @@ public class Cursor extends Boxed {
     /**
      * Create a new cursor from a pixmap.
      */
-    public Cursor(Pixmap source, Pixmap mask, 
-                  Color fg, Color bg, 
-                  int x, int y) {
+    public Cursor(Pixmap source, Pixmap mask, Color fg, Color bg, int x, int y) {
         super(gdk_cursor_new_from_pixmap(source.getHandle(), mask.getHandle(),
-                                         fg.getHandle(), bg.getHandle(), 
-                                         x, y));
+                fg.getHandle(), bg.getHandle(), x, y));
     }
 
     /**
      * Package private helper method.
      */
-    static Cursor getCursorFromHandle( Handle hndl ) {
-        if ( hndl != null ) {
-            Boxed box = Boxed.getBoxedFromHandle( hndl );
-            return ( box != null ) ? (Cursor)box : new Cursor(hndl);
+    static Cursor getCursorFromHandle(Handle hndl) {
+        if (hndl != null) {
+            Boxed box = Boxed.getBoxedFromHandle(hndl);
+            return (box != null) ? (Cursor) box : new Cursor(hndl);
         }
         return null;
     }
 
     native static final protected int getType(Handle obj);
+
     native static final protected Handle gdk_cursor_new(int cursorType);
-    native static final protected Handle gdk_cursor_new_from_pixmap(Handle source, Handle mask, Handle fg, Handle bg, int x, int y);
+
+    native static final protected Handle gdk_cursor_new_from_pixmap(
+            Handle source, Handle mask, Handle fg, Handle bg, int x, int y);
 }
