@@ -12,22 +12,20 @@ package org.gnu.gdk;
 import org.gnu.glib.Handle;
 
 /**
- *
+ * 
  */
-public class EventNoExpose extends Event
-{
+public class EventNoExpose extends Event {
     /**
-     * Promotion constructor. Construct the specific event object by
-     * promoting (sharing the <tt>Handle</tt> object of) the base
-     * <tt>Event</tt>.
+     * Promotion constructor. Construct the specific event object by promoting
+     * (sharing the <tt>Handle</tt> object of) the base <tt>Event</tt>.
      */
-    public EventNoExpose( Event evt ) {
-        // We share the handle with both instances.  This avoids
+    public EventNoExpose(Event evt) {
+        // We share the handle with both instances. This avoids
         // copying the event (via the constructor ( super( evt ) ).
         // It is more of a "promotion" constructor.
-        super( evt.getHandle() );
+        super(evt.getHandle());
     }
-	
+
     public EventNoExpose(Handle handle) {
         super(handle);
     }
@@ -40,6 +38,7 @@ public class EventNoExpose extends Event
         return getSendEvent(getHandle());
     }
 
-    native static final protected Handle getWindow (Handle obj);
-    native static final protected boolean getSendEvent (Handle obj);
+    native static final protected Handle getWindow(Handle obj);
+
+    native static final protected boolean getSendEvent(Handle obj);
 }
