@@ -13,15 +13,13 @@ import org.gnu.glib.MemStruct;
 import org.gnu.glib.Handle;
 
 /**
- * Gives the window manager information about a window's geometry
- * constraints.
+ * Gives the window manager information about a window's geometry constraints.
  */
-public class Geometry extends MemStruct 
-{
+public class Geometry extends MemStruct {
     public int getMinWidth() {
         return getMinWidth(getHandle());
     }
-    
+
     public int getMaxWidth() {
         return getMaxWidth(getHandle());
     }
@@ -29,50 +27,59 @@ public class Geometry extends MemStruct
     public int getMinHeight() {
         return getMinHeight(getHandle());
     }
-    
+
     public int getMaxHeight() {
         return getMaxHeight(getHandle());
     }
-    
+
     public int getBaseWidth() {
         return getBaseWidth(getHandle());
     }
-    
+
     public int getBaseHeight() {
         return getBaseHeight(getHandle());
     }
-    
+
     public int getWidthIncrement() {
         return getWidthInc(getHandle());
     }
-    
+
     public int getHeightIncrement() {
         return getHeightInc(getHandle());
     }
-    
+
     public double getMinAspect() {
         return getMinAspect(getHandle());
     }
-    
+
     public double getMaxAspect() {
         return getMaxAspect(getHandle());
     }
-    
+
     public Gravity getWindowGravity() {
         return Gravity.intern(getWinGravity(getHandle()));
     }
-    
-    native static final protected int getMinWidth (Handle obj);
-    native static final protected int getMinHeight (Handle obj);
-    native static final protected int getMaxWidth (Handle obj);
-    native static final protected int getMaxHeight (Handle obj);
-    native static final protected int getBaseWidth (Handle obj);
-    native static final protected int getBaseHeight (Handle obj);
-    native static final protected int getWidthInc (Handle obj);
-    native static final protected int getHeightInc (Handle obj);
-    native static final protected double getMinAspect (Handle obj);
-    native static final protected double getMaxAspect (Handle obj);
-    native static final protected int getWinGravity (Handle obj);
+
+    native static final protected int getMinWidth(Handle obj);
+
+    native static final protected int getMinHeight(Handle obj);
+
+    native static final protected int getMaxWidth(Handle obj);
+
+    native static final protected int getMaxHeight(Handle obj);
+
+    native static final protected int getBaseWidth(Handle obj);
+
+    native static final protected int getBaseHeight(Handle obj);
+
+    native static final protected int getWidthInc(Handle obj);
+
+    native static final protected int getHeightInc(Handle obj);
+
+    native static final protected double getMinAspect(Handle obj);
+
+    native static final protected double getMaxAspect(Handle obj);
+
+    native static final protected int getWinGravity(Handle obj);
 
 }
-
