@@ -14,44 +14,42 @@ import org.gnu.glib.Type;
 import org.gnu.glib.Handle;
 
 /**
- *
+ * 
  */
-public class Accessible extends AtkObject 
-{
-	
-	public Accessible(Handle handle) {
-		super(handle);
-	}
-    
+public class Accessible extends AtkObject {
+
+    public Accessible(Handle handle) {
+        super(handle);
+    }
+
     /**
      * Internal static factory method to be used by Java-Gnome only.
      */
     public static Accessible getAccessible(Handle handle) {
         if (handle == null)
             return null;
-        
+
         Accessible obj = (Accessible) getGObjectFromHandle(handle);
         if (obj == null)
             obj = new Accessible(handle);
-        
+
         return obj;
     }
-	
-	public Widget getWidget() {
-		Handle hndl = getWidget(getHandle());
-		return Widget.getWidget(hndl);
-	}
-	
-	/**
-	 * Retrieve the runtime type used by the GLib library.
-	 */
-	public static Type getType() {
-		return new Type(gtk_accessible_get_type());
-	}
-	
 
-    native static final protected Handle getWidget (Handle cptr);
-    native static final protected int gtk_accessible_get_type ();
+    public Widget getWidget() {
+        Handle hndl = getWidget(getHandle());
+        return Widget.getWidget(hndl);
+    }
+
+    /**
+     * Retrieve the runtime type used by the GLib library.
+     */
+    public static Type getType() {
+        return new Type(gtk_accessible_get_type());
+    }
+
+    native static final protected Handle getWidget(Handle cptr);
+
+    native static final protected int gtk_accessible_get_type();
 
 }
-
