@@ -18,7 +18,7 @@ import org.gnu.glib.Handle;
 
 /**
  */
-public class IconView extends Container {
+public class IconView extends Container implements CellLayout {
 
     /**
      * Create a new IconView
@@ -568,6 +568,64 @@ public class IconView extends Container {
                 IconViewEvent.Type.SELECTION_CHANGED, IconViewListener.class);
     }
 
+    //
+    // CellLayout interface implementation.
+    //
+
+    /**
+     * Packs the cell into the beginning of the CellLayout. If expand is FALSE,
+     * then the cell is allocated no more space than it needs. Any unused space
+     * is divided evenly between cells for which expand is TRUE.
+     */
+    public void packStart(CellRenderer renderer, boolean expand) {
+        CellLayoutHelper.packStart(this, renderer, expand);
+    }
+
+    /**
+     * Adds the cell to the end of the CellLayout. If expand is FALSE, then the
+     * cell is allocated no more space than it needs. Any unused space is
+     * divided evenly between cells for which expand is TRUE.
+     */
+    public void packEnd(CellRenderer renderer, boolean expand) {
+        CellLayoutHelper.packEnd(this, renderer, expand);
+    }
+
+    /**
+     * Unsets all the mappings on all renderers on the CellLayout and removes
+     * all renderers from the CellLayout.
+     */
+    public void clear() {
+        CellLayoutHelper.clear(this);
+    }
+
+    /**
+     * Adds an attribute mapping to the list in the CellLayout. The column is
+     * the column of the model to get a value from, and the attribute is the
+     * parameter on cell to be set from the value.
+     */
+    public void addAttributeMapping(CellRenderer renderer,
+            CellRendererAttribute attribute, DataColumn column) {
+        CellLayoutHelper.addAttributeMapping(this, renderer, attribute, column);
+    }
+
+    /**
+     * Clears all existing attributes previously set with
+     * {@link #addAttributeMapping}.
+     */
+    public void clearAttributeMappings(CellRenderer renderer) {
+        CellLayoutHelper.clearAttributeMappings(this, renderer);
+    }
+
+    /**
+     * Re-inserts the renderer at position. Note that the renderer has already
+     * to be packed into the CellLayout for this to function properly.
+     */
+    public void reorder(CellRenderer renderer, int position) {
+        CellLayoutHelper.reorder(this, renderer, position);
+    }
+
+    
+    
     native static final protected int gtk_icon_view_get_type();
 
     native static final protected Handle gtk_icon_view_new();
