@@ -9,7 +9,7 @@
 
 package org.gnu.pango;
 
-import org.gnu.javagnome.Enum;
+import org.gnu.glib.Enum;
 
 /**
  * The PangoUnderline enumeration is used to specify whether text should be
