@@ -9,18 +9,14 @@
 
 #include <jni.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_gdk_KeymapKey.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-guint32 GdkKeymapKey_get_keycode (GdkKeymapKey * cptr) 
-{
-    return cptr->keycode;
-}
-
 /*
  * Class:     org.gnu.gdk.KeymapKey
  * Method:    getKeycode
@@ -28,12 +24,7 @@ guint32 GdkKeymapKey_get_keycode (GdkKeymapKey * cptr)
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_KeymapKey_getKeycode (JNIEnv *env, jclass cls, jobject obj)
 {
     GdkKeymapKey *obj_g = (GdkKeymapKey *)getPointerFromHandle(env, obj);
-    return (jint) (GdkKeymapKey_get_keycode (obj_g));
-}
-
-gint32 GdkKeymapKey_get_group (GdkKeymapKey * cptr) 
-{
-    return cptr->group;
+    return (jint) obj_g->keycode;
 }
 
 /*
@@ -44,12 +35,7 @@ gint32 GdkKeymapKey_get_group (GdkKeymapKey * cptr)
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_KeymapKey_getGroup (JNIEnv *env, jclass cls, jobject obj) 
 {
     GdkKeymapKey *obj_g = (GdkKeymapKey *)getPointerFromHandle(env, obj);
-    return (jint) (GdkKeymapKey_get_group (obj_g));
-}
-
-gint32 GdkKeymapKey_get_level (GdkKeymapKey * cptr) 
-{
-    return cptr->level;
+    return (jint) obj_g->group;
 }
 
 /*
@@ -60,7 +46,7 @@ gint32 GdkKeymapKey_get_level (GdkKeymapKey * cptr)
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_KeymapKey_getLevel (JNIEnv *env, jclass cls, jobject obj) 
 {
     GdkKeymapKey *obj_g = (GdkKeymapKey *)getPointerFromHandle(env, obj);
-    return (jint) (GdkKeymapKey_get_level (obj_g));
+    return (jint) obj_g->level;
 }
 
 
