@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_HScrollBar.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -34,7 +36,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HScrollBar_gtk_1hscrollbar_1new (JNIE
     cls, jobject adjustment) 
 {
     GtkAdjustment *adjustment_g = (GtkAdjustment *)getPointerFromHandle(env, adjustment);
-    return getHandleFromPointer(env, gtk_hscrollbar_new (adjustment_g));
+    return getGObjectHandle(env, (GObject *) gtk_hscrollbar_new (adjustment_g));
 }
 
 
